package com.hikcreate.edl.pub.web.mobile.infra.data.cache;

import cn.hutool.core.date.DateTime;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.hikcreate.common.sdk.response.apiparam.ResponseGenerator;
import com.hikcreate.edl.pub.web.mobile.infra.data.mapper.BindInfoMapper;
import com.hikcreate.edl.pub.web.mobile.infra.model.BindInfo;
import org.springframework.cache.annotation.CacheEvict;
import org.springframework.cache.annotation.Cacheable;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.util.List;

/**
 * @author lixian
 * @description
 * @date 2020/6/21 15:49
 **/
@Component
public class BindCache {
    @Resource
    private BindInfoMapper mapper;

    /**
     * 获取绑定信息
     * @param unqId
     * @return
     */
    @Cacheable( value = "bindinfo", key = "'id:'+#unqId", unless = "#result==null" )
    public BindInfo getById( String unqId ) {
        LambdaQueryWrapper<BindInfo> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.eq(BindInfo::getUnqId, unqId);
        queryWrapper.eq(BindInfo::getStatus, 1);
        return mapper.selectOne(queryWrapper);
    }

    /**
     * 查询用户绑定信息
     * @param userId    第三方用户ID
     * @return
     */
    @Cacheable( value = "bindinfo", key = "'userId:'+#userId", unless = "#result==null or #result.size()==0" )
    public List<BindInfo> selectByQuery( String userId) {
        return mapper.selectByQuery(userId);
    }

    /**
     * 解绑
     * @param unqId
     * @return
     */
    @CacheEvict( value = "bindinfo", key = "'id:'+#unqId", condition = "#unqId!=null")
    public boolean unBind(String unqId){
        BindInfo bindInfo = new BindInfo();
        bindInfo.setUnqId(unqId);
        bindInfo.setStatus("0");
        bindInfo.setUnbindTime(DateTime.now().toString());
        return mapper.unbind(bindInfo) > 0 ;
    }
}
